@@ -66,7 +66,7 @@ Changing a class method, by example
 
 =cut
 
-$Sub::Mage::VERSION = '0.003';
+$Sub::Mage::VERSION = '0.006';
 $Sub::Mage::Subs = {};
 $Sub::Mage::Imports = [];
 $Sub::Mage::Debug = 0;
@@ -77,6 +77,7 @@ sub import {
     my ($class, @args) = @_;
     my $pkg = caller;
     
+    my $moosed;
     if (@args > 0) {
         for (@args) {
             feature->import( ':5.10' )
@@ -84,20 +85,45 @@ sub import {
             
             _debug_on()
                 if $_ eq ':Debug';
+            
+            _setup_class($pkg)
+                if $_ eq ':Class';
+            
+            $moosed = 1
+                if $_ eq ':Moose';
         }
     }
 
-    _import_def(
-        $pkg,
-        qw/
-            override
-            restore
-            after
-            before
-            conjur
-            sub_alert
-        /,
-    );
+    if ($moosed) {
+        _import_def(
+            $pkg,
+            qw/
+                conjur
+                sub_alert
+                duplicate
+            /,
+        );
+    }
+    else {
+        _import_def(
+            $pkg,
+            qw/
+                override
+                restore
+                after
+                before
+                conjur
+                sub_alert
+                duplicate
+            /,
+        );
+    }
+}
+
+sub _setup_class {
+    my $class = shift;
+
+    *{ "$class\::new" } = sub { return bless { }, $class };
 }
 
 sub _import_def {
@@ -159,7 +185,7 @@ sub restore {
     $sub = "$pkg\:\:$sub";
     
     if (! exists $Sub::Mage::Subs->{$sub}) {
-        _debug("Failed to restore '$sub' because it's not in the Subs list. Was it overriden, or modified by a hook?");
+        _debug("Failed to restore '$sub' because it's not in the Subs list. Was it overriden or modified by a hook?");
         warn "I have no recollection of '$sub'";
         return 0;
     }
@@ -266,6 +292,32 @@ sub sub_alert {
     }
 }
 
+sub duplicate {
+    my ($name, %opts) = @_;
+
+    my $from;
+    my $to;
+    foreach my $opt (keys %opts) {
+        $from = $opts{$opt}
+            if $opt eq 'from';
+        $to = $opts{$opt}
+            if $opt eq 'to';
+    }
+
+    if ((! $from || ! $to )) {
+        warn "duplicate(): 'from' and 'to' needed to cast this spell";
+        return ;
+    }
+
+    if (! $from->can($name)) {
+        warn "duplicate(): $from does not have the method '$name'";
+        return ;
+    }
+
+    *{$to . "::$name"} = \*{$from . "::$name"};
+}
+        
+
 sub _debug_on {
     $Sub::Mage::Debug = 1;
     _debug("Sub::Mage debugging ON");
@@ -276,7 +328,7 @@ sub _debug {
         if $Sub::Mage::Debug == 1;
 }
 
-=head1 IMPORT
+=head1 INCANTATIONS
 
 When you C<use Sub::Mage> there are currently a couple of options you can pass to it. One is C<:5.010>. This will import the 5.010 feature.. this has nothing to do 
 with subs, but I like this module, so it's there. The other is C<:Debug>. If for some reason you want some kind of debugging going on when you override, restore, conjur 
@@ -291,8 +343,35 @@ or create hook modifiers then this will enable it for you. It can get verbose, s
     use Sub::Mage qw/:5.010 :Debug/;
 
     conjur 'asub' => sub { }; # notifies you with [debug] that a subroutine was conjured
-    
-=head1 Spells
+
+Now with importing we can turn a perfectly normal package into a class, sort of. It saves you from creating C<sub new { ... }>
+
+    # MyApp.pm
+    package MyApp;
+
+    use Sub::Mage qw/:5.010 :Class/;
+
+    1;
+
+    # test.pl
+    my $foo = MyApp->new;
+
+    MyApp->conjur( name => sub {
+        my ($self, $name) = @_;
+
+        $self->{name} = $name;
+        say "Set name to $name";
+    });
+
+    MyApp->conjur( getName => sub { return shift->{name}; });
+
+    $foo->name('World');
+
+    say $foo->getName;
+
+Above we created a basically blank package, passed :Class to the Sub::Mage import method, then controlled the entire class from C<test.pl>.
+
+=head1 SPELLS
 
 =head2 override
 
@@ -366,6 +445,17 @@ B<Very verbose>: Adds a before hook modifier to every subroutine in the package
 
     say "Hello, " . test(); # prints Hello, World but also lets you know 'test' in 'package' was called.
 
+=head2 duplicate
+
+Duplicates a subroutine from one class to another. Probably rarely used, but the feature is there if you need it.
+
+    use ThisPackage;
+    use ThatPackage;
+
+    duplicate 'subname' => ( from => 'ThisPackage', to => 'ThatPackage' );
+
+    ThatPackage->subname; # duplicate of ThisPackage->subname
+
 =head1 AUTHOR
 
 Brad Haywood <brad@geeksware.net>
